@@ -87,7 +87,8 @@ class TestCurlUtils(unittest.TestCase):
 </html>"""
         command = ["curl", "http://example.com/"]
         utils = CurlUtils(command, output)
-        lexer = utils.get_lexer(utils.contents[0].content)
+        self.assertTrue(len(utils.contents) == 2)
+        lexer = utils.get_lexer(utils.contents[1].content)
         self.assertTrue(isinstance(lexer, XmlLexer))
 
     def test_include(self):
@@ -96,28 +97,31 @@ class TestCurlUtils(unittest.TestCase):
         :return:
         """
         output = """HTTP/1.1 200 OK
-    Date: Sun, 17 May 2020 06:34:10 GMT
-    Content-Type: application/json
-    Content-Length: 267
-    Connection: keep-alive
-    Server: gunicorn/19.9.0
-    Access-Control-Allow-Origin: *
-    Access-Control-Allow-Credentials: true
+Date: Sun, 17 May 2020 06:34:10 GMT
+Content-Type: application/json
+Content-Length: 267
+Connection: keep-alive
+Server: gunicorn/19.9.0
+Access-Control-Allow-Origin: *
+Access-Control-Allow-Credentials: true
 
-    {
-      "args": {},
-      "headers": {
-        "Accept": "application/json",
-        "Host": "httpbin.org",
-        "User-Agent": "curl/7.64.1",
-        "X-Amzn-Trace-Id": "Root=1-5ec0dae2-767fbad5b9437e9dd8fd1529"
-      },
-      "origin": "103.90.76.242",
-      "url": "http://httpbin.org/get"
-    }"""
+{
+  "args": {},
+  "headers": {
+    "Accept": "application/json",
+    "Host": "httpbin.org",
+    "User-Agent": "curl/7.64.1",
+    "X-Amzn-Trace-Id": "Root=1-5ec0dae2-767fbad5b9437e9dd8fd1529"
+  },
+  "origin": "103.90.76.242",
+  "url": "http://httpbin.org/get"
+}"""
         command = ["curl", "-i", "-X", "GET", "http://httpbin.org/get", "-H" "accept: application/json"]
         utils = CurlUtils(command, output)
-        self.assertTrue(len(utils.contents) == 3)
+        print("---------------------------------")
+        print(utils.contents)
+        print("---------------------------------")
+        self.assertEqual(len(utils.contents), 2)
 
     def test_verbose(self):
         """
